@@ -1,7 +1,7 @@
 """
 It includes urlpatterns necessary for upy.contrib.images
 """
-from django.conf.urls.defaults import *
+from django.conf.urls import *
 urlpatterns = patterns('',
         (r'^img_preview$','upy.contrib.image.views.img_preview'),
 )
